==> regina-normal_4.2.orig.tar.gz: regina-4.2/engine/engine/manifold/nhandlebody.cpp <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Computational Engine                                                  *
 *                                                                        *
 *  Copyright (c) 1999-2005, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,        *
 *  MA 02111-1307, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/* end stub */

#include "algebra/nabeliangroup.h"
#include "manifold/nhandlebody.h"

namespace regina {

NAbelianGroup* NHandlebody::getHomologyH1() const {
    NAbelianGroup* ans = new NAbelianGroup();
    if (nHandles)
        ans->addRank(nHandles);
    return ans;
}

std::ostream& NHandlebody::writeName(std::ostream& out) const {
    if (nHandles == 0)
        out << "B3";
    else if (nHandles == 1) {
        if (orientable)
            out << "B2 x S1";
        else
            out << "B2 x~ S1";
    } else {
        if (orientable)
            out << "Handle-Or(" << nHandles << ')';
        else
            out << "Handle-Nor(" << nHandles << ')';
    }
    return out;
}

std::ostream& NHandlebody::writeTeXName(std::ostream& out) const {
    if (nHandles == 0)
        out << "$B^3$";
    else if (nHandles == 1) {
        if (orientable)
            out << "$B^2 \\times S^1$";
        else
            out << "$B^2 \\twisted S^1$";
    } else {
        if (orientable)
            out << "$\\mathit{Handle-Or}(" << nHandles << ")$";
        else
            out << "$\\mathit{Handle-Nor}(" << nHandles << ")$";
    }
    return out;
}

} // namespace regina

==> regina-normal_4.3.1.orig.tar.gz: regina-4.3.1/engine/engine/manifold/nhandlebody.cpp <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Computational Engine                                                  *
 *                                                                        *
 *  Copyright (c) 1999-2006, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/* end stub */

#include "algebra/nabeliangroup.h"
#include "manifold/nhandlebody.h"

namespace regina {

NAbelianGroup* NHandlebody::getHomologyH1() const {
    NAbelianGroup* ans = new NAbelianGroup();
    if (nHandles)
        ans->addRank(nHandles);
    return ans;
}

std::ostream& NHandlebody::writeName(std::ostream& out) const {
    if (nHandles == 0)
        out << "B3";
    else if (nHandles == 1) {
        if (orientable)
            out << "B2 x S1";
        else
            out << "B2 x~ S1";
    } else {
        if (orientable)
            out << "Handle-Or(" << nHandles << ')';
        else
            out << "Handle-Nor(" << nHandles << ')';
    }
    return out;
}

std::ostream& NHandlebody::writeTeXName(std::ostream& out) const {
    if (nHandles == 0)
        out << "B^3";
    else if (nHandles == 1) {
        if (orientable)
            out << "B^2 \\times S^1";
        else
            out << "B^2 \\twisted S^1";
    } else {
        if (orientable)
            out << "\\mathit{Handle-Or}(" << nHandles << ')';
        else
            out << "\\mathit{Handle-Nor}(" << nHandles << ')';
    }
    return out;
}

} // namespace regina
